summaryrefslogtreecommitdiff
path: root/pkg/domain/entities/system.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2021-10-10 12:54:29 +0200
committerGitHub <noreply@github.com>2021-10-10 12:54:29 +0200
commit60c711f78956f4eda1f811757dc8b320e5e66d9f (patch)
tree851f1a5766e15066ba64b527bf26a85fb27f3554 /pkg/domain/entities/system.go
parentc47f714fe8193cd1ac90a9359da3ef177a6db7e1 (diff)
parent8d3aec9d08bddf486dcb30e7113777b9d0cc27bd (diff)
downloadpodman-60c711f78956f4eda1f811757dc8b320e5e66d9f.tar.gz
podman-60c711f78956f4eda1f811757dc8b320e5e66d9f.tar.bz2
podman-60c711f78956f4eda1f811757dc8b320e5e66d9f.zip
Merge pull request #11869 from jwhonce/wip/pprof
Enable /debug/pprof API service endpoints
Diffstat (limited to 'pkg/domain/entities/system.go')
-rw-r--r--pkg/domain/entities/system.go11
1 files changed, 5 insertions, 6 deletions
diff --git a/pkg/domain/entities/system.go b/pkg/domain/entities/system.go
index cca4bf44e..fe041dec8 100644
--- a/pkg/domain/entities/system.go
+++ b/pkg/domain/entities/system.go
@@ -6,15 +6,14 @@ import (
"github.com/containers/podman/v3/libpod/define"
"github.com/containers/podman/v3/pkg/domain/entities/reports"
"github.com/containers/podman/v3/pkg/domain/entities/types"
- "github.com/spf13/cobra"
)
// ServiceOptions provides the input for starting an API Service
type ServiceOptions struct {
- URI string // Path to unix domain socket service should listen on
- Timeout time.Duration // duration of inactivity the service should wait before shutting down
- Command *cobra.Command // CLI command provided. Used in V1 code
- CorsHeaders string // CORS headers
+ CorsHeaders string // Cross-Origin Resource Sharing (CORS) headers
+ PProfAddr string // Network address to bind pprof profiles service
+ Timeout time.Duration // Duration of inactivity the service should wait before shutting down
+ URI string // Path to unix domain socket service should listen on
}
// SystemPruneOptions provides options to prune system.
@@ -6,15 +6,14 @@ import (
)
-// ServiceOptions provides the input for starting an API Service
+// ServiceOptions provides the input for starting an API and sidecar pprof services
type ServiceOptions struct {